@@ -1,4 +1,4 @@
 from ghostipy.dsp.filtering import *
 from ghostipy.dsp.firfilter import *
+from ghostipy.dsp.analytic import *
 #from ghostipy.dsp.convolution import *
-#from ghostipy.dsp.analytic import *
