@@ -1,6 +1,7 @@
 import logging
 import pyfftw
 import dask
+import warnings
 import numpy as np
 
 import time
@@ -13,9 +14,7 @@ from ghostipy.spectral.wavelets import (Wavelet, MorseWavelet, AmorWavelet, Bump
 
 __all__ = ['cwt']
 
-# @pre.standardize_asa(x='data', fs='fs', n_signals=1, 
-#                         class_method=False, abscissa_vals='timestamps')
-def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
+def cwt(data, *, fs=1, timestamps=None, wavelet=MorseWavelet(gamma=3, beta=20),
                 freq_limits=None, freqs=None, voices_per_octave=10,
                 n_workers=cpu_count(), verbose=False, method='full',
                 derivative=False, remove_mean=False, boundary='mirror',
@@ -32,7 +31,8 @@ def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
     timestamps : np.ndarray, with shape (n_timepoints, ) optional
         Timestamps corresponding to the data, in seconds.
         If None, they will be computed automatically based on the
-        assumption that all the data are one contiguous block.
+        assumption that all the data are one contiguous block, and
+        the units will be in seconds.
     wavelet : ghostipy.wavelet
         Type of wavelet to use for the transform.
         Default is a Morse wavelet with beta=3 and gamma=20.
@@ -155,7 +155,7 @@ def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
     w_ref_high = np.pi
     if verbose:
         print(
-            f"Smallest reference frequency: {normalized_rad_to_hz(w_ref_low, fs)} Hz")
+            f"Smallest reference frequency: {normalized_rad_to_hz(w_ref_low, fs):0.4f} Hz")
 
     if freqs is not None:
         # just in case user didn't pass in sorted
@@ -165,27 +165,26 @@ def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
         w_low = ws[0]
         w_high = ws[-1]
         if w_low < w_ref_low:
-            print(
+            warnings.warn(
                 f"Warning: Lower frequency limit of {freq_limits[0]} is less than the smallest "
-                f"recommended frequency of {normalized_rad_to_hz(w_ref_low, fs)} Hz")
+                f"recommended frequency of {normalized_rad_to_hz(w_ref_low, fs):0.4f} Hz")
         if w_high > w_ref_high:
-            print(
+            warnings.warn(
                 f"Warning: Upper frequency limit of {freq_limits[1]} is greater than the largest "
-                f"recommended frequency of {normalized_rad_to_hz(w_ref_high, fs)} Hz")
+                f"recommended frequency of {normalized_rad_to_hz(w_ref_high, fs):0.4f} Hz")
     elif freq_limits is not None:
         # just in case user didn't pass in limits as [lower_bound, upper_bound]
         freq_limits = np.sort(freq_limits)
         w_low = hz_to_normalized_rad(freq_limits[0], fs)
         w_high = hz_to_normalized_rad(freq_limits[1], fs)
         if w_low < w_ref_low:
-            print(
+            warnings.warn(
                 f"Lower frequency limit of {freq_limits[0]} is less than the smallest "
-                f"recommended frequency of {normalized_rad_to_hz(w_ref_low, fs)} Hz")
+                f"recommended frequency of {normalized_rad_to_hz(w_ref_low, fs):0.4f} Hz")
         if w_high > w_ref_high:
-            print(
+            warnings.warn(
                 f"Upper frequency limit of {freq_limits[1]} is greater than the largest "
-                f"recommended frequency of {normalized_rad_to_hz(w_ref_high, fs)} Hz")
-        print(w_low, w_ref_low, w_high, w_ref_high)
+                f"recommended frequency of {normalized_rad_to_hz(w_ref_high, fs):0.4f} Hz")
     else:
         w_low = w_ref_low
         w_high = w_ref_high
@@ -206,7 +205,7 @@ def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
     
     extend_len = int(np.ceil(np.max(cois)))
     if extend_len > N:
-        print(f"Warning: Cannot add {extend_len} points to satisfy requested"
+        warnings.warn(f"Cannot add {extend_len} points to satisfy requested"
                 f" boundary policy. Shorting this value to data length {N}")
         extend_len = N
     
@@ -222,17 +221,20 @@ def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
     # Set up array as C contiguous since we will be iterating row-by-row
     n_bits = len(scales) * data.shape[0] * 16
     if verbose:
-        print(f"{n_bits/1e9} GB = {n_bits/(1024**3)} GiB required")
+        print(f"Output space requirement: {n_bits/1e9} GB = {n_bits/(1024**3)} GiB")
 
     output_shape = (scales.shape[0], N)
     dtype = '<c16'
     if describe_dims:
         if verbose:
+            print("Calculating output array sizes. Skipping transform computation")
             print(f"Output array with 'derivative' {derivative}"
                   f" should have shape {output_shape} with dtype {dtype}")
         return output_shape, dtype
 
     if cwt_out is not None:
+        if verbose:
+            print("Using passed-in output array")
         if cwt_out.shape != output_shape:
             raise ValueError(
                 f"Provided output array has shape {coefs.shape}"
@@ -240,12 +242,9 @@ def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
         coefs = cwt_out
     else:
         if verbose:
-            print("Pre-allocating output array")
+            print("Allocating output array")
         coefs = pyfftw.zeros_aligned(output_shape, dtype='complex128')
 
-    if verbose:
-        print(f"extend_len is {extend_len}, data shape is {data.shape}")
-
     ######################################################################
     # Set up CWT parallel computation
 
@@ -303,7 +302,7 @@ def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
         print('CWT total elapsed time: {} seconds'.format(time.time() - t0))
 
     if timestamps is None:
-        timestamps = np.arange(data.shape) / fs
+        timestamps = np.arange(N) / fs
     
     return coefs, scales, normalized_rad_to_hz(ws, fs), timestamps, cois
 
@@ -360,41 +359,35 @@ def _cwt_ola_fftw(data, wavelet, scale, derivative, cwt, ii,
 
     psif = np.zeros((1, N), dtype='<c16')
     omega = np.fft.fftfreq(N) * 2 * np.pi
-#     if dask:
+
     wavelet.freq_domain_numba(
         omega,
         np.atleast_1d(scale),
         psif,
         derivative=derivative)
-#     else:
-#         wavelet.freq_domain_numba(omega,
-#                                   np.atleast_1d(scale),
-#                                   psif)
-
 
     if not wavelet.is_analytic:
         psif = psif.conj()
-    #cwt = np.zeros(len(data), dtype='<c16')
-    #cwt = np.empty(len(data), dtype='<f8')
-
 
     ########################################################################
     x = pyfftw.zeros_aligned(N, dtype='complex128')
     # using powers of 4 so FFTW_ESTIMATE should suffice
     # in place transform to save memory
-    fft_sig = pyfftw.FFTW( x, x,
-                           direction='FFTW_FORWARD',
-                           flags=['FFTW_ESTIMATE'],
-                           threads=threads)
+    fft_sig = pyfftw.FFTW( 
+        x, x,
+        direction='FFTW_FORWARD',
+        flags=['FFTW_ESTIMATE'],
+        threads=threads)
 
     y = pyfftw.zeros_aligned(N, dtype='complex128')
     y[:] = psif
 
     conv_res = pyfftw.zeros_aligned(N, dtype='complex128')
-    fft_conv_inv = pyfftw.FFTW(conv_res, conv_res,
-                          direction='FFTW_BACKWARD', 
-                          flags=['FFTW_ESTIMATE'], 
-                          threads=threads)
+    fft_conv_inv = pyfftw.FFTW(
+        conv_res, conv_res,
+        direction='FFTW_BACKWARD', 
+        flags=['FFTW_ESTIMATE'], 
+        threads=threads)
 
     #######################################################################
     first_block_to_check, first_offset = divmod(extend_len, N - 2*M)
@@ -445,31 +438,6 @@ def _cwt_ola_fftw(data, wavelet, scale, derivative, cwt, ii,
             outarray_marker += n_samples
         else:
             pass
-#         else:
-#             cwt[ii, outarray_marker:outarray_marker + len(cwt_chunk)] = cwt_chunk
-#             outarray_marker += len(cwt_chunk)
-
-
-    ########################################################################
-#     for buf_start in buf_starts:
-
-#         seg_start = max(buf_start - M, start)
-#         seg_end = min(seg_start + N, stop)
-
-#         chunk = data[seg_start:seg_end]
-
-#         x[:len(chunk)] = chunk
-#         x[len(chunk):] = 0
-#         fft_sig(normalise_idft=True)
-#         conv_res[:] = x * y
-#         fft_conv_inv(normalise_idft=True)
-
-#         res_start = buf_start - seg_start
-#         res_end = min(N - M, len(chunk))
-#         cwt_chunk = conv_res[res_start:res_end]
-
-#         #cwt[buf_start:buf_start + len(cwt_chunk)] = np.abs(cwt_chunk)
-#         cwt[ii, buf_start:buf_start + len(cwt_chunk)] = cwt_chunk
 
     return
 
@@ -478,44 +446,24 @@ def _cwt_full_fftw(data_fft, wavelet, scale, derivative, cwt, ii,
 
     out = pyfftw.zeros_aligned((1, len(data_fft)), dtype='complex128')
 
-    fft_conv_inv = pyfftw.FFTW(out, out,
-                               axes=(-1, ),
-                               direction='FFTW_BACKWARD',
-                               flags=['FFTW_ESTIMATE'],
-                               threads=threads)
+    fft_conv_inv = pyfftw.FFTW(
+        out, out,
+        axes=(-1, ),
+        direction='FFTW_BACKWARD',
+        flags=['FFTW_ESTIMATE'],
+        threads=threads)
+
+    wavelet.freq_domain_numba(
+        omega,
+        np.atleast_1d(scale),
+        out,
+        derivative=derivative)
 
-#         t0 = time.time()
-    wavelet.freq_domain_numba(omega,
-                              np.atleast_1d(scale),
-                              out,
-                              derivative=derivative)
-#         print("Finished computing wavelets in {} seconds".format(time.time() - t0))
     if not wavelet.is_analytic:
-        out = out.conj()
+        out[:] = out.conj()
+
     out *= data_fft
     fft_conv_inv(normalise_idft=True)
     cwt[ii:ii+1] = out[:, extend_len:len(data_fft)-extend_len]
-    
-    
-    #######################################
-#     else:
-#         fft_conv_inv = pyfftw.FFTW(cwt[ii], cwt[ii],
-#                                    axes=(-1, ),
-#                                    direction='FFTW_BACKWARD',
-#                                    flags=['FFTW_ESTIMATE'],
-#                                    threads=threads)
-
-# #         t0 = time.time()
-#         wavelet.freq_domain_numba(omega,
-#                                   np.atleast_1d(scale),
-#                                   cwt[ii:ii+1],
-#                                   derivative=derivative)
-# #         print("Finished computing wavelets in {} seconds".format(time.time() - t0))
-#         if not wavelet.is_analytic:
-#             cwt[ii] = cwt[ii].conj()
-#         cwt[ii] *= data_fft
-#         fft_conv_inv(normalise_idft=True)
-    
-    #######################################
 
     return
\ No newline at end of file
